@@ -1,7 +1,7 @@
 #include <R.h>
 #include <Rmath.h>
 
-void dist2(double *x1, double *x2, int *nc, int *nr1, int *nr2, double *d)
+void dist2_c(double *x1, double *x2, int *nc, int *nr1, int *nr2, double *d)
 {
 	int ncol = nc[0];
 	int nrow1 = nr1[0];
